==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/awt/WindowDescriptor.hpp <==
#ifndef _COM_SUN_STAR_AWT_WINDOWDESCRIPTOR_HPP_
#define _COM_SUN_STAR_AWT_WINDOWDESCRIPTOR_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_AWT_WINDOWDESCRIPTOR_HDL_
#include "com/sun/star/awt/WindowDescriptor.hdl"
#endif

#ifndef _COM_SUN_STAR_AWT_RECTANGLE_HPP_
#include "com/sun/star/awt/Rectangle.hpp"
#endif
#ifndef _COM_SUN_STAR_AWT_WINDOWCLASS_HPP_
#include "com/sun/star/awt/WindowClass.hpp"
#endif
#ifndef _COM_SUN_STAR_AWT_XWINDOWPEER_HPP_
#include "com/sun/star/awt/XWindowPeer.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace awt {

inline WindowDescriptor::WindowDescriptor() SAL_THROW( () )
    : Type(::com::sun::star::awt::WindowClass_TOP)
    , WindowServiceName()
    , Parent()
    , ParentIndex(0)
    , Bounds()
    , WindowAttributes(0)
{
}

inline WindowDescriptor::WindowDescriptor(const ::com::sun::star::awt::WindowClass& Type_, const ::rtl::OUString& WindowServiceName_, const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindowPeer >& Parent_, const ::sal_Int16& ParentIndex_, const ::com::sun::star::awt::Rectangle& Bounds_, const ::sal_Int32& WindowAttributes_) SAL_THROW( () )
    : Type(Type_)
    , WindowServiceName(WindowServiceName_)
    , Parent(Parent_)
    , ParentIndex(ParentIndex_)
    , Bounds(Bounds_)
    , WindowAttributes(WindowAttributes_)
{
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::awt::WindowDescriptor const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.awt.WindowDescriptor");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_AWT_WINDOWDESCRIPTOR_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/awt/WindowDescriptor.hpp <==
#ifndef _COM_SUN_STAR_AWT_WINDOWDESCRIPTOR_HPP_
#define _COM_SUN_STAR_AWT_WINDOWDESCRIPTOR_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_AWT_WINDOWDESCRIPTOR_HDL_
#include "com/sun/star/awt/WindowDescriptor.hdl"
#endif

#ifndef _COM_SUN_STAR_AWT_RECTANGLE_HPP_
#include "com/sun/star/awt/Rectangle.hpp"
#endif
#ifndef _COM_SUN_STAR_AWT_WINDOWCLASS_HPP_
#include "com/sun/star/awt/WindowClass.hpp"
#endif
#ifndef _COM_SUN_STAR_AWT_XWINDOWPEER_HPP_
#include "com/sun/star/awt/XWindowPeer.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace awt {

inline WindowDescriptor::WindowDescriptor() SAL_THROW( () )
    : Type(::com::sun::star::awt::WindowClass_TOP)
    , WindowServiceName()
    , Parent()
    , ParentIndex(0)
    , Bounds()
    , WindowAttributes(0)
{
}

inline WindowDescriptor::WindowDescriptor(const ::com::sun::star::awt::WindowClass& Type_, const ::rtl::OUString& WindowServiceName_, const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindowPeer >& Parent_, const ::sal_Int16& ParentIndex_, const ::com::sun::star::awt::Rectangle& Bounds_, const ::sal_Int32& WindowAttributes_) SAL_THROW( () )
    : Type(Type_)
    , WindowServiceName(WindowServiceName_)
    , Parent(Parent_)
    , ParentIndex(ParentIndex_)
    , Bounds(Bounds_)
    , WindowAttributes(WindowAttributes_)
{
}

} } } }

namespace com { namespace sun { namespace star { namespace awt {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::awt::WindowDescriptor const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.awt.WindowDescriptor");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::awt::WindowDescriptor const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::awt::WindowDescriptor >::get();
}

#endif // _COM_SUN_STAR_AWT_WINDOWDESCRIPTOR_HPP_
